@@ -1,6 +1,7 @@
 /*
     Anacron - run commands periodically
     Copyright (C) 1998  Itai Tzur <itzur@actcom.co.il>
+    Copyright (C) 1999  Sean 'Shaleh' Perry <shaleh@debian.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +21,8 @@
     `COPYING' that comes with the Anacron source distribution.
 */
 
+#ifndef _ANACRON_GLOBAL_H
+#define _ANACRON_GLOBAL_H
 
 /* Syslog facility and priorities messages will be logged to (see syslog(3)).
  * If you change these, please update the man page. */
@@ -71,6 +74,7 @@ typedef struct job_rec1 job_rec;
 
 extern pid_t primary_pid;
 extern char *program_name;
+extern char *anacrontab;
 extern int old_umask;
 extern sigset_t old_sigmask;
 extern int serialize,force,update_only,now,no_daemon,quiet;
@@ -93,27 +97,19 @@ extern int running_jobs,running_mailers;
 /* Function prototypes */
 
 /* main.c */
-int xopen(int fd, char *file_name, int flags);
+int xopen(int fd, const char *file_name, int flags);
 void xclose(int fd);
 pid_t xfork();
 
 /* log.c */
-void explain(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void explain_e(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void complain(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void complain_e(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void die(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void die_e(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void xdebug(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
-void xdebug_e(char *fmt, ...)
-__attribute__ ((format (printf, 1, 2)));
+void explain(const char *fmt, ...);
+void explain_e(const char *fmt, ...);
+void complain(const char *fmt, ...);
+void complain_e(const char *fmt, ...);
+void die(const char *fmt, ...);
+void die_e(const char *fmt, ...);
+void xdebug(const char *fmt, ...);
+void xdebug_e(const char *fmt, ...);
 void xcloselog();
 
 #ifdef DEBUG
@@ -137,3 +133,5 @@ void fake_job(job_rec *jr);
 /* runjob.c */
 void tend_children();
 void launch_job(job_rec *jr);
+
+#endif
