@@ -1,7 +1,7 @@
 /*
     Anacron - run commands periodically
     Copyright (C) 1998  Itai Tzur <itzur@actcom.co.il>
-	Copyright (C) 1999  Sean 'Shaleh' Perry <shaleh@debian.org>
+    Copyright (C) 1999  Sean 'Shaleh' Perry <shaleh@debian.org>
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,51 +63,54 @@ day_num(int year, int month, int day)
  * and your local library.
  */
 {
-	int dn;
-	int i;
-	const int isleap = leap(year); /* save three calls to leap() */
+    int dn;
+    int i;
+    const int isleap; /* save three calls to leap() */
 
-	/* Some validity checks */
+    /* Some validity checks */
 
-	/* we don't deal with B.C. years here */
-	if (year < 1) return - 1;
-	/* conservative overflow estimate */
-	if (year > (INT_MAX / 366)) return - 1;
-	if (month > 12 || month < 1) return - 1;
-	if (day < 1) return - 1;
-	if (month != 2) {
-		if(day > days_in_month[month - 1]) return - 1;
-	}
-	else if ((isleap && day > 29) || (!isleap && day > 28))
-			return - 1;
+    /* we don't deal with B.C. years here */
+    if (year < 1) return - 1;
+    /* conservative overflow estimate */
+    if (year > (INT_MAX / 366)) return - 1;
+    if (month > 12 || month < 1) return - 1;
+    if (day < 1) return - 1;
+  
+    isleap = leap(year);
+  
+    if (month != 2) {
+	if(day > days_in_month[month - 1]) return - 1;
+    }
+    else if ((isleap && day > 29) || (!isleap && day > 28))
+	return - 1;
 
-	/* First calculate the day number of December 31 last year */
+    /* First calculate the day number of December 31 last year */
 
- 	/* save us from doing (year - 1) over and over */
-	i = year - 1;
-	/* 365 days in a "regular" year + number of leap days */
-	dn = (i * 365) + (i / 4) - (i / 100) + (i / 400);
+    /* save us from doing (year - 1) over and over */
+    i = year - 1;
+    /* 365 days in a "regular" year + number of leap days */
+    dn = (i * 365) + ((i / 4) - (i / 100) + (i / 400));
 
-	/* Now, day number of the last day of the previous month */
+    /* Now, day number of the last day of the previous month */
 
-	for (i = month - 1; i > 0; --i)
-		dn += days_in_month[i - 1];
-	/* Add 29 February ? */
-	if (month > 2 && isleap) ++dn;
+    for (i = month - 1; i > 0; --i)
+	dn += days_in_month[i - 1];
+    /* Add 29 February ? */
+    if (month > 2 && isleap) ++dn;
 
-	/* How many days into month are we */
+    /* How many days into month are we */
 
-	dn += day;
+    dn += day;
 
-	return dn;
+    return dn;
 }
 
 static int
 leap(int year)
 /* Is this a leap year ? */
 {
-	/* every year exactly divisible by 4 is "leap" */
-	/* unless it is exactly divisible by 100 */
-	/* but not by 400 */
-	return (year % 4 == 0 && (year % 100 != 0 || year % 400 == 0));
+    /* every year exactly divisible by 4 is "leap" */
+    /* unless it is exactly divisible by 100 */
+    /* but not by 400 */
+    return (year % 4 == 0 && (year % 100 != 0 || year % 400 == 0));
 }
