@@ -1,6 +1,7 @@
 /*
     Anacron - run commands periodically
     Copyright (C) 1998  Itai Tzur <itzur@actcom.co.il>
+    Copyright (C) 1999  Sean 'Shaleh' Perry <shaleh@debian.org>
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,141 +51,141 @@ static int log_open = 0;
 static void
 xopenlog()
 {
-	if (!log_open)
-	{
-		openlog(program_name, LOG_PID, SYSLOG_FACILITY);
-		log_open = 1;
-	}
+    if (!log_open)
+    {
+	openlog(program_name, LOG_PID, SYSLOG_FACILITY);
+	log_open = 1;
+    }
 }
 
 void
 xcloselog()
 {
-	if (log_open) closelog();
-	log_open = 0;
+    if (log_open) closelog();
+    log_open = 0;
 }
 
 static void
-make_msg(char *fmt, va_list args)
+make_msg(const char *fmt, va_list args)
 /* Construct the message string from its parts */
 {
-	int len;
+    int len;
 
-	/* There's some confusion in the documentation about what vsnprintf
-	 * returns when the buffer overflows.  Hmmm... */
-	len = vsnprintf(msg, sizeof(msg), fmt, args);
-	if (len >= sizeof(msg) - 1)
-		strcpy(msg + sizeof(msg) - sizeof(truncated), truncated);
+    /* There's some confusion in the documentation about what vsnprintf
+     * returns when the buffer overflows.  Hmmm... */
+    len = vsnprintf(msg, sizeof(msg), fmt, args);
+    if (len >= sizeof(msg) - 1)
+	strcpy(msg + sizeof(msg) - sizeof(truncated), truncated);
 }
 
 static void
-log(int priority, char *fmt, va_list args)
+log(int priority, const char *fmt, va_list args)
 /* Log a message, described by "fmt" and "args", with the specified
  * "priority". */
 {
-	make_msg(fmt, args);
-	xopenlog();
-	syslog(priority, "%s", msg);
-	if (!in_background)
-	{
-		if (priority == EXPLAIN_LEVEL && !quiet)
-			fprintf(stderr, "%s\n", msg);
-		else if (priority == COMPLAIN_LEVEL)
-			fprintf(stderr, "%s: %s\n", program_name, msg);
-	}
+    make_msg(fmt, args);
+    xopenlog();
+    syslog(priority, "%s", msg);
+    if (!in_background)
+    {
+	if (priority == EXPLAIN_LEVEL && !quiet)
+	    fprintf(stderr, "%s\n", msg);
+	else if (priority == COMPLAIN_LEVEL)
+	    fprintf(stderr, "%s: %s\n", program_name, msg);
+    }
 }
 
 static void
-log_e(int priority, char *fmt, va_list args)
+log_e(int priority, const char *fmt, va_list args)
 /* Same as log(), but also appends an error description corresponding
  * to "errno". */
 {
-	int saved_errno;
+    int saved_errno;
 
-	saved_errno = errno;
-	make_msg(fmt, args);
-	xopenlog();
-	syslog(priority, "%s: %s", msg, strerror(saved_errno));
-	if (!in_background)
-	{
-		if (priority == EXPLAIN_LEVEL && !quiet)
-			fprintf(stderr, "%s: %s\n", msg, strerror(saved_errno));
-		else if (priority == COMPLAIN_LEVEL)
-			fprintf(stderr, "%s: %s: %s\n",
-        			program_name, msg, strerror(saved_errno));
-	}
+    saved_errno = errno;
+    make_msg(fmt, args);
+    xopenlog();
+    syslog(priority, "%s: %s", msg, strerror(saved_errno));
+    if (!in_background)
+    {
+	if (priority == EXPLAIN_LEVEL && !quiet)
+	    fprintf(stderr, "%s: %s\n", msg, strerror(saved_errno));
+	else if (priority == COMPLAIN_LEVEL)
+	    fprintf(stderr, "%s: %s: %s\n",
+		    program_name, msg, strerror(saved_errno));
+    }
 }
 
 void
-explain(char *fmt, ...)
+explain(const char *fmt, ...)
 /* Log an "explain" level message */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log(EXPLAIN_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log(EXPLAIN_LEVEL, fmt, args);
+    va_end(args);
 }
 
 void
-explain_e(char *fmt, ...)
+explain_e(const char *fmt, ...)
 /* Log an "explain" level message, with an error description */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log_e(EXPLAIN_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log_e(EXPLAIN_LEVEL, fmt, args);
+    va_end(args);
 }
 
 void
-complain(char *fmt, ...)
+complain(const char *fmt, ...)
 /* Log a "complain" level message */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log(COMPLAIN_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log(COMPLAIN_LEVEL, fmt, args);
+    va_end(args);
 }
 
 void
-complain_e(char *fmt, ...)
+complain_e(const char *fmt, ...)
 /* Log a "complain" level message, with an error description */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log_e(COMPLAIN_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log_e(COMPLAIN_LEVEL, fmt, args);
+    va_end(args);
 }
 
 void
-die(char *fmt, ...)
+die(const char *fmt, ...)
 /* Log a "complain" level message, and exit */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log(COMPLAIN_LEVEL, fmt, args);
-	va_end(args);
-	if (getpid() == primary_pid) complain("Aborted");
+    va_start(args, fmt);
+    log(COMPLAIN_LEVEL, fmt, args);
+    va_end(args);
+    if (getpid() == primary_pid) complain("Aborted");
 
-	exit(FAILURE_EXIT);
+    exit(FAILURE_EXIT);
 }
 
 void
-die_e(char *fmt, ...)
+die_e(const char *fmt, ...)
 /* Log a "complain" level message, with an error description, and exit */
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log_e(COMPLAIN_LEVEL, fmt, args);
-	va_end(args);
-	if (getpid() == primary_pid) complain("Aborted");
+    va_start(args, fmt);
+    log_e(COMPLAIN_LEVEL, fmt, args);
+    va_end(args);
+    if (getpid() == primary_pid) complain("Aborted");
 
-	exit(FAILURE_EXIT);
+    exit(FAILURE_EXIT);
 }
 
 #ifdef DEBUG
@@ -193,23 +194,23 @@ die_e(char *fmt, ...)
  * in global.h */
 
 void
-xdebug(char *fmt, ...)
+xdebug(const char *fmt, ...)
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log(DEBUG_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log(DEBUG_LEVEL, fmt, args);
+    va_end(args);
 }
 
 void
-xdebug_e(char *fmt, ...)
+xdebug_e(const char *fmt, ...)
 {
-	va_list args;
+    va_list args;
 
-	va_start(args, fmt);
-	log_e(DEBUG_LEVEL, fmt, args);
-	va_end(args);
+    va_start(args, fmt);
+    log_e(DEBUG_LEVEL, fmt, args);
+    va_end(args);
 }
 
 #endif  /* DEBUG */
