@@ -1,6 +1,7 @@
 /*
     Anacron - run commands periodically
     Copyright (C) 1998  Itai Tzur <itzur@actcom.co.il>
+    Copyright (C) 1999  Sean 'Shaleh' Perry <shaleh@debian.org>
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +29,7 @@
 #include "matchrx.h"
 
 int
-match_rx(char *rx, char *string, int n_sub,  /* char **substrings */...)
+match_rx(const char *rx, char *string, int n_sub,  /* char **substrings */...)
 /* Return 1 if the regular expression "*rx" matches the string "*string",
  * 0 if not, -1 on error.
  * "Extended" regular expressions are used.
